==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/BlazorCodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { DotNetCodeGeneratingComponentRendererModuleEmitter } from "./DotNetCodeGeneratingComponentRendererModuleEmitter";
import { markType } from "./type";
/**
 * @hidden
 */
var BlazorCodeGeneratingComponentRendererModuleEmitter = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BlazorCodeGeneratingComponentRendererModuleEmitter, _super);
    function BlazorCodeGeneratingComponentRendererModuleEmitter(a, b, c) {
        var _this = _super.call(this, a, b, c) || this;
        _this.w = null;
        _this.x = 0;
        return _this;
    }
    BlazorCodeGeneratingComponentRendererModuleEmitter.prototype.p = function () {
        _super.prototype.p.call(this);
    };
    BlazorCodeGeneratingComponentRendererModuleEmitter.prototype.m = function (a) {
        _super.prototype.m.call(this, a);
        if (this.x > 0) {
            this.d.l(", ");
        }
        var b = "";
        var c = a.split('/');
        if (c.length == 1) {
            b = c[0];
        }
        else {
            b = c[1];
        }
        if (b == "withDescriptions") {
            this.d.j("typeof(IgbInputModule)");
        }
        else {
            this.d.j("typeof(");
            this.d.j("Igb" + b);
            this.d.j(")");
        }
        this.x++;
    };
    BlazorCodeGeneratingComponentRendererModuleEmitter.prototype.o = function () {
        _super.prototype.o.call(this);
    };
    BlazorCodeGeneratingComponentRendererModuleEmitter.$t = markType(BlazorCodeGeneratingComponentRendererModuleEmitter, 'BlazorCodeGeneratingComponentRendererModuleEmitter', DotNetCodeGeneratingComponentRendererModuleEmitter.$);
    return BlazorCodeGeneratingComponentRendererModuleEmitter;
}(DotNetCodeGeneratingComponentRendererModuleEmitter));
export { BlazorCodeGeneratingComponentRendererModuleEmitter };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/BlazorCodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { DotNetCodeGeneratingComponentRendererModuleEmitter } from "./DotNetCodeGeneratingComponentRendererModuleEmitter";
import { markType } from "./type";
/**
 * @hidden
 */
var BlazorCodeGeneratingComponentRendererModuleEmitter = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BlazorCodeGeneratingComponentRendererModuleEmitter, _super);
    function BlazorCodeGeneratingComponentRendererModuleEmitter(a, b, c) {
        var _this = _super.call(this, a, b, c) || this;
        _this.w = null;
        _this.x = 0;
        return _this;
    }
    BlazorCodeGeneratingComponentRendererModuleEmitter.prototype.p = function () {
        _super.prototype.p.call(this);
    };
    BlazorCodeGeneratingComponentRendererModuleEmitter.prototype.m = function (a, b, c) {
        _super.prototype.m.call(this, a, b, c);
        if (this.x > 0) {
            this.d.l(", ");
        }
        var d = "";
        var e = b.split('/');
        if (e.length == 1) {
            d = e[0];
        }
        else {
            d = e[1];
        }
        if (d == "withDescriptions") {
            this.d.j("typeof(IgbInputModule)");
        }
        else {
            this.d.j("typeof(");
            this.d.j("Igb" + d);
            this.d.j(")");
        }
        this.x++;
    };
    BlazorCodeGeneratingComponentRendererModuleEmitter.prototype.o = function () {
        _super.prototype.o.call(this);
    };
    BlazorCodeGeneratingComponentRendererModuleEmitter.$t = markType(BlazorCodeGeneratingComponentRendererModuleEmitter, 'BlazorCodeGeneratingComponentRendererModuleEmitter', DotNetCodeGeneratingComponentRendererModuleEmitter.$);
    return BlazorCodeGeneratingComponentRendererModuleEmitter;
}(DotNetCodeGeneratingComponentRendererModuleEmitter));
export { BlazorCodeGeneratingComponentRendererModuleEmitter };
